test Package
============

:mod:`test` Package
-------------------

.. automodule:: camelot.test
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`http_proxy` Module
------------------------

.. automodule:: camelot.test.http_proxy
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_field_attributes` Module
-----------------------------------

.. automodule:: camelot.test.test_field_attributes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_proxy` Module
------------------------

.. automodule:: camelot.test.test_proxy
    :members:
    :undoc-members:
    :show-inheritance:

